:mod:`xoutil.data` - Useful data-structures and data related algorithms
========================================================================

.. automodule:: xoutil.data
   :members: adapt_exception
